@@ -5,5 +5,7 @@ from . import forms
 
 class WebcamPictureField(ImageField):
     def formfield(self, **kwargs):
-        kwargs["form_class"] = forms.WebcamPictureFormField
-        return super().formfield(**kwargs)
+        defaults = {"form_class": forms.WebcamPictureFormField}
+        defaults.update(kwargs)
+
+        return super().formfield(**defaults)
